@@ -34,6 +34,8 @@ def get_client(access_key_id, secret_access_key, region, profile):
 @click.option('--cpu', type=(str, int), multiple=True, help='Overwrites the cpu value for a container: <container> <cpu>')
 @click.option('--memory', type=(str, int), multiple=True, help='Overwrites the memory value for a container: <container> <memory>')
 @click.option('--memoryreservation', type=(str, int), multiple=True, help='Overwrites the memory reservation value for a container: <container> <memoryreservation>')
+@click.option('--task-cpu', type=int, help='Overwrites the cpu value for a task: <cpu>')
+@click.option('--task-memory', type=int, help='Overwrites the memory value for a task: <memory>')
 @click.option('--privileged', type=(str, bool), multiple=True, help='Overwrites the privileged value for a container: <container> <privileged>')
 @click.option('--essential', type=(str, bool), multiple=True, help='Overwrites the essential value for a container: <container> <essential>')
 @click.option('-e', '--env', type=(str, str, str), multiple=True, help='Adds or changes an environment variable: <container> <name> <value>')
@@ -48,6 +50,7 @@ def get_client(access_key_id, secret_access_key, region, profile):
 @click.option('-l', '--log', type=(str, str, str, str), multiple=True, help='Adds or changes a log configuration in the container description (Not available for Fargate): <container> <log driver> <option name> <option value>')
 @click.option('-r', '--role', type=str, help='Sets the task\'s role ARN: <task role ARN>')
 @click.option('-x', '--execution-role', type=str, help='Sets the execution\'s role ARN: <execution role ARN>')
+@click.option('--runtime-platform', type=str, nargs=2, help='Overwrites runtimePlatform: <cpuArchitecture> <operatingSystemFamily>')
 @click.option('--task', type=str, help='Task definition to be deployed. Can be a task ARN or a task family with optional revision')
 @click.option('--region', required=False, help='AWS region (e.g. eu-central-1)')
 @click.option('--access-key-id', required=False, help='AWS access key id')
@@ -78,19 +81,18 @@ def get_client(access_key_id, secret_access_key, region, profile):
 @click.option('--volume', type=(str, str), multiple=True, required=False, help='Set volume mapping from host to container in the task definition.')
 @click.option('--add-container', type=str, multiple=True, required=False, help='Add a placeholder container in the task definition.')
 @click.option('--remove-container', type=str, multiple=True, required=False, help='Remove a container from the task definition.')
-def deploy(cluster, service, tag, image, command, health_check, cpu, memory, memoryreservation, privileged, essential, env, env_file, s3_env_file, secret, ulimit, system_control, port, mount, log, role, execution_role, task, region, access_key_id, secret_access_key, profile, timeout, newrelic_apikey, newrelic_appid, newrelic_region, newrelic_revision, comment, user, ignore_warnings, diff, deregister, rollback, exclusive_env, exclusive_secrets, exclusive_s3_env_file, sleep_time, exclusive_ulimits, exclusive_system_controls, exclusive_ports, exclusive_mounts, volume, add_container, remove_container, slack_url, docker_label, exclusive_docker_labels, slack_service_match='.*'):
+def deploy(cluster, service, tag, image, command, health_check, cpu, memory, memoryreservation, task_cpu, task_memory, privileged, essential, env, env_file, s3_env_file, secret, ulimit, system_control, port, mount, log, role, execution_role, runtime_platform, task, region, access_key_id, secret_access_key, profile, timeout, newrelic_apikey, newrelic_appid, newrelic_region, newrelic_revision, comment, user, ignore_warnings, diff, deregister, rollback, exclusive_env, exclusive_secrets, exclusive_s3_env_file, sleep_time, exclusive_ulimits, exclusive_system_controls, exclusive_ports, exclusive_mounts, volume, add_container, remove_container, slack_url, docker_label, exclusive_docker_labels, slack_service_match='.*'):
     """
     Redeploy or modify a service.
 
     \b
-    CLUSTER is the name of your cluster (e.g. 'my-custer') within ECS.
+    CLUSTER is the name of your cluster (e.g. 'my-cluster') within ECS.
     SERVICE is the name of your service (e.g. 'my-app') within ECS.
 
     When not giving any other options, the task definition will not be changed.
     It will just be duplicated, so that all container images will be pulled
     and redeployed.
     """
-
     try:
         client = get_client(access_key_id, secret_access_key, region, profile)
         deployment = DeployAction(client, cluster, service)
@@ -105,6 +107,8 @@ def deploy(cluster, service, tag, image, command, health_check, cpu, memory, mem
         td.set_cpu(**{key: value for (key, value) in cpu})
         td.set_memory(**{key: value for (key, value) in memory})
         td.set_memoryreservation(**{key: value for (key, value) in memoryreservation})
+        td.set_task_cpu(task_cpu)
+        td.set_task_memory(task_memory)
         td.set_privileged(**{key: value for (key, value) in privileged})
         td.set_essential(**{key: value for (key, value) in essential})
         td.set_environment(env, exclusive_env, env_file)
@@ -118,6 +122,7 @@ def deploy(cluster, service, tag, image, command, health_check, cpu, memory, mem
         td.set_log_configurations(log)
         td.set_role_arn(role)
         td.set_execution_role_arn(execution_role)
+        td.set_runtime_platform(runtime_platform)
         td.set_volumes(volume)
 
         slack = SlackNotification(
@@ -175,6 +180,8 @@ def deploy(cluster, service, tag, image, command, health_check, cpu, memory, mem
 @click.option('--cpu', type=(str, int), multiple=True, help='Overwrites the cpu value for a container: <container> <cpu>')
 @click.option('--memory', type=(str, int), multiple=True, help='Overwrites the memory value for a container: <container> <memory>')
 @click.option('--memoryreservation', type=(str, int), multiple=True, help='Overwrites the memory reservation value for a container: <container> <memoryreservation>')
+@click.option('--task-cpu', type=int, help='Overwrites the cpu value for a task: <cpu>')
+@click.option('--task-memory', type=int, help='Overwrites the memory value for a task: <memory>')
 @click.option('--privileged', type=(str, bool), multiple=True, help='Overwrites the memory reservation value for a container: <container> <memoryreservation>')
 @click.option('-e', '--env', type=(str, str, str), multiple=True, help='Adds or changes an environment variable: <container> <name> <value>')
 @click.option('-s', '--secret', type=(str, str, str), multiple=True, help='Adds or changes a secret environment variable from the AWS Parameter Store (Not available for Fargate): <container> <name> <parameter name>')
@@ -212,12 +219,12 @@ def deploy(cluster, service, tag, image, command, health_check, cpu, memory, mem
 @click.option('--exclusive-ports', is_flag=True, default=False, help='Set the given port mappings exclusively and remove all other pre-existing port mappings from all containers')
 @click.option('--exclusive-mounts', is_flag=True, default=False, help='Set the given mount points exclusively and remove all other pre-existing mount points from all containers')
 @click.option('--volume', type=(str, str), multiple=True, required=False, help='Set volume mapping from host to container in the task definition.')
-def cron(cluster, task, rule, image, tag, command, cpu, memory, memoryreservation, privileged, env, env_file, s3_env_file, secret, ulimit, system_control, port, mount, log, role, execution_role, region, access_key_id, secret_access_key, newrelic_apikey, newrelic_appid, newrelic_region, newrelic_revision, comment, user, profile, diff, deregister, rollback, exclusive_env, exclusive_secrets, exclusive_s3_env_file, slack_url, slack_service_match, exclusive_ulimits, exclusive_system_controls, exclusive_ports, exclusive_mounts, volume, docker_label, exclusive_docker_labels):
+def cron(cluster, task, rule, image, tag, command, cpu, memory, memoryreservation, task_cpu, task_memory, privileged, env, env_file, s3_env_file, secret, ulimit, system_control, port, mount, log, role, execution_role, region, access_key_id, secret_access_key, newrelic_apikey, newrelic_appid, newrelic_region, newrelic_revision, comment, user, profile, diff, deregister, rollback, exclusive_env, exclusive_secrets, exclusive_s3_env_file, slack_url, slack_service_match, exclusive_ulimits, exclusive_system_controls, exclusive_ports, exclusive_mounts, volume, docker_label, exclusive_docker_labels):
     """
     Update a scheduled task.
 
     \b
-    CLUSTER is the name of your cluster (e.g. 'my-custer') within ECS.
+    CLUSTER is the name of your cluster (e.g. 'my-cluster') within ECS.
     TASK is the name of your task definition (e.g. 'my-task') within ECS.
     RULE is the name of the rule to use the new task definition.
     """
@@ -233,6 +240,8 @@ def cron(cluster, task, rule, image, tag, command, cpu, memory, memoryreservatio
         td.set_cpu(**{key: value for (key, value) in cpu})
         td.set_memory(**{key: value for (key, value) in memory})
         td.set_memoryreservation(**{key: value for (key, value) in memoryreservation})
+        td.set_task_cpu(task_cpu)
+        td.set_task_memory(task_memory)
         td.set_privileged(**{key: value for (key, value) in privileged})
         td.set_environment(env, exclusive_env, env_file)
         td.set_docker_labels(docker_label, exclusive_docker_labels)
@@ -289,6 +298,7 @@ def cron(cluster, task, rule, image, tag, command, cpu, memory, memoryreservatio
 @click.option('-s', '--secret', type=(str, str, str), multiple=True, help='Adds or changes a secret environment variable from the AWS Parameter Store (Not available for Fargate): <container> <name> <parameter name>')
 @click.option('-d', '--docker-label', type=(str, str, str), multiple=True, help='Adds or changes a docker label: <container> <name> <value>')
 @click.option('-r', '--role', type=str, help='Sets the task\'s role ARN: <task role ARN>')
+@click.option('--runtime-platform', type=str, nargs=2, help='Overwrites runtimePlatform: <cpuArchitecture> <operatingSystemFamily>')
 @click.option('--region', help='AWS region (e.g. eu-central-1)')
 @click.option('--access-key-id', help='AWS access key id')
 @click.option('--secret-access-key', help='AWS secret access key')
@@ -299,7 +309,7 @@ def cron(cluster, task, rule, image, tag, command, cpu, memory, memoryreservatio
 @click.option('--exclusive-docker-labels', is_flag=True, default=False, help='Set the given docker labels exclusively and remove all other pre-existing docker-labels from all containers')
 @click.option('--exclusive-s3-env-file', is_flag=True, default=False, help='Set the given s3 env files exclusively and remove all other pre-existing s3 env files from all containers')
 @click.option('--deregister/--no-deregister', default=True, help='Deregister or keep the old task definition (default: --deregister)')
-def update(task, image, tag, command, env, env_file, s3_env_file, secret, role, region, access_key_id, secret_access_key, profile, diff, exclusive_env, exclusive_s3_env_file, exclusive_secrets, deregister, docker_label, exclusive_docker_labels):
+def update(task, image, tag, command, env, env_file, s3_env_file, secret, role, region, access_key_id, secret_access_key, profile, diff, exclusive_env, exclusive_s3_env_file, exclusive_secrets, runtime_platform, deregister, docker_label, exclusive_docker_labels):
     """
     Update a task definition.
 
@@ -320,6 +330,7 @@ def update(task, image, tag, command, env, env_file, s3_env_file, secret, role,
         td.set_secrets(secret, exclusive_secrets)
         td.set_s3_env_file(s3_env_file, exclusive_s3_env_file)
         td.set_role_arn(role)
+        td.set_runtime_platform(runtime_platform)
 
         if diff:
             print_diff(td)
@@ -350,7 +361,7 @@ def scale(cluster, service, desired_count, access_key_id, secret_access_key, reg
     Scale a service up or down.
 
     \b
-    CLUSTER is the name of your cluster (e.g. 'my-custer') within ECS.
+    CLUSTER is the name of your cluster (e.g. 'my-cluster') within ECS.
     SERVICE is the name of your service (e.g. 'my-app') within ECS.
     DESIRED_COUNT is the number of tasks your service should run.
     """
@@ -406,7 +417,7 @@ def run(cluster, task, count, command, env, env_file, s3_env_file, secret, launc
     Run a one-off task.
 
     \b
-    CLUSTER is the name of your cluster (e.g. 'my-custer') within ECS.
+    CLUSTER is the name of your cluster (e.g. 'my-cluster') within ECS.
     TASK is the name of your task definition (e.g. 'my-task') within ECS.
     COUNT is the number of tasks your service should run.
     """
@@ -491,7 +502,8 @@ def diff(task, revision_a, revision_b, region, access_key_id, secret_access_key,
 
 def wait_for_finish(action, timeout, title, success_message, failure_message,
                     ignore_warnings, sleep_time=1):
-    click.secho(title, nl=False)
+    click.secho(title)
+    start_timestamp = datetime.now()
     waiting_timeout = datetime.now() + timedelta(seconds=timeout)
     service = action.get_service()
     inspected_until = None
@@ -524,7 +536,8 @@ def wait_for_finish(action, timeout, title, success_message, failure_message,
         timeout=waiting
     )
 
-    click.secho('\n%s\n' % success_message, fg='green')
+    click.secho('\n%s' % success_message, fg='green')
+    click.secho('Duration: %s sec\n' % (datetime.now() - start_timestamp).seconds)
 
 
 def deploy_task_definition(deployment, task_definition, title, success_message,
